==> pipewire-docs-1%3A0.3.33-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/structdevice.js <==
var structdevice =
[
    [ "active_profile", "structdevice.html#addc5816afac7f0f226fbf650ba4bd899", null ],
    [ "appeared", "structdevice.html#ae4996ddd2af5f95f7997b02243e6243f", null ],
    [ "best_profile", "structdevice.html#adc5dbf4473b50ec08efa9df65489e879", null ],
    [ "device", "structdevice.html#a7f14acae03a4965f70510757b092c569", null ],
    [ "device", "structdevice.html#a612ddbd2df868839014be2caf0b54da3", null ],
    [ "device_id", "structdevice.html#a52e563b2755afba84d42f931a130192a", null ],
    [ "device_listener", "structdevice.html#a0d8fd18fc9d353dca18968395b240deb", null ],
    [ "endpoint_list", "structdevice.html#a3ab75bf859d0f1ae31f942c3c98a5fbb", null ],
    [ "factory_name", "structdevice.html#af1edb2d592e40fdd099ad8bf3c40a953", null ],
    [ "first", "structdevice.html#a4947f8ca412414c01da8911bc9bba86a", null ],
    [ "generation", "structdevice.html#a86ab0e80e147d440c57dbd1241e4ccdc", null ],
    [ "handle", "structdevice.html#a08e839dc675c9a4dbb9518d562b3e182", null ],
    [ "id", "structdevice.html#a9e253146638c4751711e811f4f65cf6c", null ],
    [ "impl", "structdevice.html#af3fb4db235a8feafcf36ea82f7f57b17", null ],
    [ "key", "structdevice.html#acd93cbb47c0075b2ab54b82bcba2fea5", null ],
    [ "link", "structdevice.html#a9717de7a4d6f684f97105ef9f6a20b4d", null ],
    [ "listener", "structdevice.html#a8bae18c4cba2816d6a171c89c5158d79", null ],
    [ "n_acquired", "structdevice.html#a03c0a8a14097e605017a60eadc59729d", null ],
    [ "name", "structdevice.html#ab94dff3eb87e96eb7aa089f1138008db", null ],
    [ "node_list", "structdevice.html#af4a1911d2134c5557a449dd1f54fc8ad", null ],
    [ "obj", "structdevice.html#aeae756cb2b446c4b2f9b90ff425e244b", null ],
    [ "pending_profile", "structdevice.html#ab6fd4a380412e8e2a6664598431a693e", null ],
    [ "priority", "structdevice.html#a642fde1d1dbdd9d28b51cea97baaab1a", null ],
    [ "probed", "structdevice.html#a443459be488d46e7939befdf9039e456", null ],
    [ "profile", "structdevice.html#ab7eb090c918e3287decd7122dafed467", null ],
    [ "props", "structdevice.html#a0a3a7199afefea7b690408bd5da7c56b", null ],
    [ "reserve", "structdevice.html#a7f8d83754ec993ece2f4a77d4eb51272", null ],
    [ "restored", "structdevice.html#a1599a058c03f9a2ba6581ff32c537687", null ],
    [ "route_info", "structdevice.html#a494f0bc317fe2af6d8030afdb2d8a6e9", null ],
    [ "saved_profile", "structdevice.html#a177f5fa653b7176e275dc7a0cfb25228", null ],
    [ "sdevice", "structdevice.html#abf34b167c23d5f9c253eeb4b5849103a", null ],
    [ "seq", "structdevice.html#a5d10fce27295adf12b63dfd045059d33", null ],
    [ "sync_listener", "structdevice.html#a4110196160ac83d56dcb7e978ae29e52", null ],
    [ "use_acp", "structdevice.html#a8473cd498709750d24428caca2a1eec9", null ]
];

==> pipewire-docs-1%3A0.3.34-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/structdevice.js <==
var structdevice =
[
    [ "active_profile", "structdevice.html#addc5816afac7f0f226fbf650ba4bd899", null ],
    [ "appeared", "structdevice.html#ae4996ddd2af5f95f7997b02243e6243f", null ],
    [ "best_profile", "structdevice.html#adc5dbf4473b50ec08efa9df65489e879", null ],
    [ "device", "structdevice.html#a7f14acae03a4965f70510757b092c569", null ],
    [ "device", "structdevice.html#a612ddbd2df868839014be2caf0b54da3", null ],
    [ "device_id", "structdevice.html#a52e563b2755afba84d42f931a130192a", null ],
    [ "device_listener", "structdevice.html#a0d8fd18fc9d353dca18968395b240deb", null ],
    [ "endpoint_list", "structdevice.html#a3ab75bf859d0f1ae31f942c3c98a5fbb", null ],
    [ "factory_name", "structdevice.html#af1edb2d592e40fdd099ad8bf3c40a953", null ],
    [ "first", "structdevice.html#a4947f8ca412414c01da8911bc9bba86a", null ],
    [ "generation", "structdevice.html#a86ab0e80e147d440c57dbd1241e4ccdc", null ],
    [ "handle", "structdevice.html#a08e839dc675c9a4dbb9518d562b3e182", null ],
    [ "id", "structdevice.html#a9e253146638c4751711e811f4f65cf6c", null ],
    [ "impl", "structdevice.html#af3fb4db235a8feafcf36ea82f7f57b17", null ],
    [ "key", "structdevice.html#acd93cbb47c0075b2ab54b82bcba2fea5", null ],
    [ "link", "structdevice.html#a9717de7a4d6f684f97105ef9f6a20b4d", null ],
    [ "listener", "structdevice.html#a8bae18c4cba2816d6a171c89c5158d79", null ],
    [ "n_acquired", "structdevice.html#a03c0a8a14097e605017a60eadc59729d", null ],
    [ "name", "structdevice.html#ab94dff3eb87e96eb7aa089f1138008db", null ],
    [ "node_list", "structdevice.html#af4a1911d2134c5557a449dd1f54fc8ad", null ],
    [ "obj", "structdevice.html#aeae756cb2b446c4b2f9b90ff425e244b", null ],
    [ "pending_profile", "structdevice.html#ab6fd4a380412e8e2a6664598431a693e", null ],
    [ "priority", "structdevice.html#a642fde1d1dbdd9d28b51cea97baaab1a", null ],
    [ "probed", "structdevice.html#a443459be488d46e7939befdf9039e456", null ],
    [ "profile", "structdevice.html#ab7eb090c918e3287decd7122dafed467", null ],
    [ "props", "structdevice.html#a0a3a7199afefea7b690408bd5da7c56b", null ],
    [ "reserve", "structdevice.html#a7f8d83754ec993ece2f4a77d4eb51272", null ],
    [ "restore_saved_profile", "structdevice.html#a06689beb7b68373cbf9dcf3061f207d6", null ],
    [ "route_info", "structdevice.html#a494f0bc317fe2af6d8030afdb2d8a6e9", null ],
    [ "sdevice", "structdevice.html#abf34b167c23d5f9c253eeb4b5849103a", null ],
    [ "seq", "structdevice.html#a5d10fce27295adf12b63dfd045059d33", null ],
    [ "sync_listener", "structdevice.html#a4110196160ac83d56dcb7e978ae29e52", null ],
    [ "use_acp", "structdevice.html#a8473cd498709750d24428caca2a1eec9", null ]
];
